Package: seqinr
Title: Biological Sequences Retrieval and Analysis
Version: 4.2-44
Depends: R (>= 2.10.0)
Imports: ade4,segmented
Authors@R: c(person("Delphine", "Charif", role = "aut"),
             person("Olivier", "Clerc", role = "ctb"),
             person("Carolin", "Frank", role = "ctb"),
             person(c("Jean", "R."), "Lobry", role = c("aut", "cph")),
             person("Anamaria", "Necşulea", role = "ctb"),
             person("Leonor", "Palmeira", role = "ctb"),
             person("Simon", "Penel", role = "cre", email = "simon.penel@univ-lyon1.fr"),
             person("Guy", "Perrière", role = "ctb"))
Maintainer: Simon Penel <simon.penel@univ-lyon1.fr>
License: GPL (>= 2)
Description: Exploratory data analysis and data visualization
  for biological sequence (DNA and protein) data. Seqinr includes
  utilities for sequence data management under the ACNUC system
  described in Gouy, M. et al. (1984) Nucleic Acids Res.
  12:121-127 <doi:10.1093/nar/12.1Part1.121>.
URL: https://github.com/lbbe-software/seqinr
BugReports: https://github.com/lbbe-software/seqinr/issues
SystemRequirements: zlib headers and library.
NeedsCompilation: yes
Encoding: UTF-8
Packaged: 2026-04-28 07:45:02 UTC; simon
Author: Delphine Charif [aut],
  Olivier Clerc [ctb],
  Carolin Frank [ctb],
  Jean R. Lobry [aut, cph],
  Anamaria Necşulea [ctb],
  Leonor Palmeira [ctb],
  Simon Penel [cre],
  Guy Perrière [ctb]
Repository: CRAN
Date/Publication: 2026-04-28 08:30:02 UTC
