# Export all names
useDynLib(seqinr, .registration = TRUE,.fixes = "C_")
exportPattern("^[^C_]")
importFrom("ade4", "dudi.coa")
importFrom("grDevices", "col2rgb", "grey", "rainbow", "rgb")
importFrom("graphics", "abline", "axis", "box", "dotchart", "hist",
             "image", "legend", "lines", "mtext", "par", "plot",
             "plot.new", "plot.window", "points", "polygon", "rect",
             "segments", "text", "title")
importFrom("stats", "as.dist", "complete.cases", "cor", "density",
             "dnorm", "integrate", "kruskal.test", "lm", "nlm",
             "optimize", "runif", "splinefun", "t.test")
importFrom("utils", "data", "download.file", "packageDescription",
             "read.table", "str", "tail")
S3method(as.matrix, alignment)
S3method(getAnnot, SeqAcnucWeb)
S3method(getAnnot, SeqFastaAA)
S3method(getAnnot, SeqFastadna)
S3method(getAnnot, default)
S3method(getAnnot, list)
S3method(getAnnot, logical)
S3method(getAnnot, qaw)
S3method(getFrag, SeqAcnucWeb)
S3method(getFrag, SeqFastaAA)
S3method(getFrag, SeqFastadna)
S3method(getFrag, SeqFrag)
S3method(getFrag, character)
S3method(getFrag, default)
S3method(getFrag, list)
S3method(getFrag, logical)
S3method(getFrag, qaw)
S3method(getKeyword, SeqAcnucWeb)
S3method(getKeyword, default)
S3method(getKeyword, list)
S3method(getKeyword, logical)
S3method(getKeyword, qaw)
S3method(getLength, SeqAcnucWeb)
S3method(getLength, SeqFastaAA)
S3method(getLength, SeqFastadna)
S3method(getLength, SeqFrag)
S3method(getLength, character)
S3method(getLength, default)
S3method(getLength, list)
S3method(getLength, logical)
S3method(getLength, qaw)
S3method(getLocation, SeqAcnucWeb)
S3method(getLocation, default)
S3method(getLocation, list)
S3method(getLocation, logical)
S3method(getLocation, qaw)
S3method(getName, SeqAcnucWeb)
S3method(getName, SeqFastaAA)
S3method(getName, SeqFastadna)
S3method(getName, SeqFrag)
S3method(getName, default)
S3method(getName, list)
S3method(getName, logical)
S3method(getName, qaw)
S3method(getSequence, SeqAcnucWeb)
S3method(getSequence, SeqFastaAA)
S3method(getSequence, SeqFastadna)
S3method(getSequence, SeqFrag)
S3method(getSequence, character)
S3method(getSequence, default)
S3method(getSequence, list)
S3method(getSequence, logical)
S3method(getSequence, qaw)
S3method(getTrans, SeqAcnucWeb)
S3method(getTrans, SeqFastadna)
S3method(getTrans, SeqFrag)
S3method(getTrans, character)
S3method(getTrans, default)
S3method(getTrans, list)
S3method(getTrans, logical)
S3method(getTrans, qaw)
S3method(plot, SeqAcnucWeb)
S3method(print, SeqAcnucWeb)
S3method(print, qaw)
S3method(summary, SeqFastaAA)
S3method(summary, SeqFastadna)
